Class: Arfi::Commands::Init
- Inherits:
-
Thor
- Object
- Thor
- Arfi::Commands::Init
- Defined in:
- lib/arfi/commands/init.rb
Overview
Initializes ARFI directory structure inside a Rails project.
Creates/ensures:
-
db/functions/public
-
db/functions/<adapter>/public (when adapter provided)
Constant Summary collapse
- ADAPTERS =
%i[postgresql mysql].freeze
- ROOT_DIR =
'db/functions'- DEFAULT_SCHEMA =
'public'
Instance Method Summary collapse
-
#create ⇒ void
Run the full init flow: validate schema, create base dirs, and optionally create adapter dirs.
Instance Method Details
#create ⇒ void
This method returns an undefined value.
Run the full init flow: validate schema, create base dirs, and optionally create adapter dirs.
34 35 36 37 38 |
# File 'lib/arfi/commands/init.rb', line 34 def create validate_schema_format! create_base_dirs create_adapter_dirs if [:adapter] # steep:ignore NoMethod end |